# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class IpsecGatewayInterface(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'hostname': 'str',
        'certificate_dn': 'str'
    }

    attribute_map = {
        'name': 'name',
        'hostname': 'hostname',
        'certificate_dn': 'certificate_dn'
    }

    def __init__(self, name=None, hostname=None, certificate_dn=None, local_vars_configuration=None):  # noqa: E501
        """IpsecGatewayInterface - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._hostname = None
        self._certificate_dn = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if hostname is not None:
            self.hostname = hostname
        if certificate_dn is not None:
            self.certificate_dn = certificate_dn

    @property
    def name(self):
        """Gets the name of this IpsecGatewayInterface.  # noqa: E501

        Name of the gateway interface. This name must be a legal RFC1123 label, and corresponds to the subdomain of the gateway interface.   # noqa: E501

        :return: The name of this IpsecGatewayInterface.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IpsecGatewayInterface.

        Name of the gateway interface. This name must be a legal RFC1123 label, and corresponds to the subdomain of the gateway interface.   # noqa: E501

        :param name: The name of this IpsecGatewayInterface.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 63):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `63`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and not re.search(r'^([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])', name)):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])/`")  # noqa: E501

        self._name = name

    @property
    def hostname(self):
        """Gets the hostname of this IpsecGatewayInterface.  # noqa: E501

        The hostname of the gateway interface. This is readOnly, and is generated from the name plus the gateway domain name.   # noqa: E501

        :return: The hostname of this IpsecGatewayInterface.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this IpsecGatewayInterface.

        The hostname of the gateway interface. This is readOnly, and is generated from the name plus the gateway domain name.   # noqa: E501

        :param hostname: The hostname of this IpsecGatewayInterface.  # noqa: E501
        :type: str
        """

        self._hostname = hostname

    @property
    def certificate_dn(self):
        """Gets the certificate_dn of this IpsecGatewayInterface.  # noqa: E501

        Certificate distinguished name (DN) subject of the gateway interface  # noqa: E501

        :return: The certificate_dn of this IpsecGatewayInterface.  # noqa: E501
        :rtype: str
        """
        return self._certificate_dn

    @certificate_dn.setter
    def certificate_dn(self, certificate_dn):
        """Sets the certificate_dn of this IpsecGatewayInterface.

        Certificate distinguished name (DN) subject of the gateway interface  # noqa: E501

        :param certificate_dn: The certificate_dn of this IpsecGatewayInterface.  # noqa: E501
        :type: str
        """

        self._certificate_dn = certificate_dn

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IpsecGatewayInterface):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IpsecGatewayInterface):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.agent_connector_proxy_request_stats import AgentConnectorProxyRequestStats  # noqa: E501
from agilicus_api.rest import ApiException

class TestAgentConnectorProxyRequestStats(unittest.TestCase):
    """AgentConnectorProxyRequestStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AgentConnectorProxyRequestStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.agent_connector_proxy_request_stats.AgentConnectorProxyRequestStats()  # noqa: E501
        if include_optional :
            return AgentConnectorProxyRequestStats(
                last_request_start_time = '2020-07-07T15:49:51.230Z', 
                bytes_received = 0, 
                bytes_sent = 0, 
                requests = agilicus_api.models.agent_connector_proxy_request_stats_details.AgentConnectorProxyRequestStatsDetails(
                    started = 0, 
                    finished = 0, 
                    status_1xx = 0, 
                    status_2xx = 0, 
                    status_3xx = 0, 
                    status_4xx = 0, 
                    status_5xx = 0, 
                    status_unknown = 0, 
                    failed_authentication = 0, 
                    failed_authorisation = 0, )
            )
        else :
            return AgentConnectorProxyRequestStats(
                bytes_received = 0,
                bytes_sent = 0,
                requests = agilicus_api.models.agent_connector_proxy_request_stats_details.AgentConnectorProxyRequestStatsDetails(
                    started = 0, 
                    finished = 0, 
                    status_1xx = 0, 
                    status_2xx = 0, 
                    status_3xx = 0, 
                    status_4xx = 0, 
                    status_5xx = 0, 
                    status_unknown = 0, 
                    failed_authentication = 0, 
                    failed_authorisation = 0, ),
        )

    def testAgentConnectorProxyRequestStats(self):
        """Test AgentConnectorProxyRequestStats"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class X509CertificateStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'not_before': 'datetime',
        'not_after': 'datetime',
        'renewal_time': 'datetime'
    }

    attribute_map = {
        'not_before': 'not_before',
        'not_after': 'not_after',
        'renewal_time': 'renewal_time'
    }

    def __init__(self, not_before=None, not_after=None, renewal_time=None, local_vars_configuration=None):  # noqa: E501
        """X509CertificateStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._not_before = None
        self._not_after = None
        self._renewal_time = None
        self.discriminator = None

        if not_before is not None:
            self.not_before = not_before
        if not_after is not None:
            self.not_after = not_after
        if renewal_time is not None:
            self.renewal_time = renewal_time

    @property
    def not_before(self):
        """Gets the not_before of this X509CertificateStatus.  # noqa: E501

        date/time for which certificate is valid  # noqa: E501

        :return: The not_before of this X509CertificateStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._not_before

    @not_before.setter
    def not_before(self, not_before):
        """Sets the not_before of this X509CertificateStatus.

        date/time for which certificate is valid  # noqa: E501

        :param not_before: The not_before of this X509CertificateStatus.  # noqa: E501
        :type: datetime
        """

        self._not_before = not_before

    @property
    def not_after(self):
        """Gets the not_after of this X509CertificateStatus.  # noqa: E501

        date/time of certificate expiry  # noqa: E501

        :return: The not_after of this X509CertificateStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._not_after

    @not_after.setter
    def not_after(self, not_after):
        """Sets the not_after of this X509CertificateStatus.

        date/time of certificate expiry  # noqa: E501

        :param not_after: The not_after of this X509CertificateStatus.  # noqa: E501
        :type: datetime
        """

        self._not_after = not_after

    @property
    def renewal_time(self):
        """Gets the renewal_time of this X509CertificateStatus.  # noqa: E501

        date/time of certificate renewal  # noqa: E501

        :return: The renewal_time of this X509CertificateStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._renewal_time

    @renewal_time.setter
    def renewal_time(self, renewal_time):
        """Sets the renewal_time of this X509CertificateStatus.

        date/time of certificate renewal  # noqa: E501

        :param renewal_time: The renewal_time of this X509CertificateStatus.  # noqa: E501
        :type: datetime
        """

        self._renewal_time = renewal_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, X509CertificateStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, X509CertificateStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.x509_certificate_spec import X509CertificateSpec  # noqa: E501
from agilicus_api.rest import ApiException

class TestX509CertificateSpec(unittest.TestCase):
    """X509CertificateSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test X509CertificateSpec
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.x509_certificate_spec.X509CertificateSpec()  # noqa: E501
        if include_optional :
            return X509CertificateSpec(
                certificate = '0', 
                csr_id = '0', 
                org_id = '123', 
                message = '0', 
                reason = 'pending'
            )
        else :
            return X509CertificateSpec(
                csr_id = '0',
                org_id = '123',
                reason = 'pending',
        )

    def testX509CertificateSpec(self):
        """Test X509CertificateSpec"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class CertSigningReqSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'org_id': 'str',
        'auto_renew': 'bool',
        'rotate_keys': 'bool',
        'request': 'str'
    }

    attribute_map = {
        'org_id': 'org_id',
        'auto_renew': 'auto_renew',
        'rotate_keys': 'rotate_keys',
        'request': 'request'
    }

    def __init__(self, org_id=None, auto_renew=True, rotate_keys=None, request=None, local_vars_configuration=None):  # noqa: E501
        """CertSigningReqSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._org_id = None
        self._auto_renew = None
        self._rotate_keys = None
        self._request = None
        self.discriminator = None

        self.org_id = org_id
        if auto_renew is not None:
            self.auto_renew = auto_renew
        if rotate_keys is not None:
            self.rotate_keys = rotate_keys
        self.request = request

    @property
    def org_id(self):
        """Gets the org_id of this CertSigningReqSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org_id of this CertSigningReqSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this CertSigningReqSpec.

        Unique identifier  # noqa: E501

        :param org_id: The org_id of this CertSigningReqSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def auto_renew(self):
        """Gets the auto_renew of this CertSigningReqSpec.  # noqa: E501

        When enabled (true), system will automatically renew the certificate using the provided request CSR.  The resulting certificate will be updated in CertSigningReqCertificateStatus.   # noqa: E501

        :return: The auto_renew of this CertSigningReqSpec.  # noqa: E501
        :rtype: bool
        """
        return self._auto_renew

    @auto_renew.setter
    def auto_renew(self, auto_renew):
        """Sets the auto_renew of this CertSigningReqSpec.

        When enabled (true), system will automatically renew the certificate using the provided request CSR.  The resulting certificate will be updated in CertSigningReqCertificateStatus.   # noqa: E501

        :param auto_renew: The auto_renew of this CertSigningReqSpec.  # noqa: E501
        :type: bool
        """

        self._auto_renew = auto_renew

    @property
    def rotate_keys(self):
        """Gets the rotate_keys of this CertSigningReqSpec.  # noqa: E501

        Provided as a mechansim to notify a user/client to rotate their keys. A client would retrieve this and the client would then issue a new request. A subsequent PUT with a new request will reset this property to false. This may be true whereby a user has decided to update all keys, and this facility could be made available via the administration portal.   # noqa: E501

        :return: The rotate_keys of this CertSigningReqSpec.  # noqa: E501
        :rtype: bool
        """
        return self._rotate_keys

    @rotate_keys.setter
    def rotate_keys(self, rotate_keys):
        """Sets the rotate_keys of this CertSigningReqSpec.

        Provided as a mechansim to notify a user/client to rotate their keys. A client would retrieve this and the client would then issue a new request. A subsequent PUT with a new request will reset this property to false. This may be true whereby a user has decided to update all keys, and this facility could be made available via the administration portal.   # noqa: E501

        :param rotate_keys: The rotate_keys of this CertSigningReqSpec.  # noqa: E501
        :type: bool
        """

        self._rotate_keys = rotate_keys

    @property
    def request(self):
        """Gets the request of this CertSigningReqSpec.  # noqa: E501

        The certificate signing request (CSR) formatted as PEM. The certificate signing request (CSR) formatted as PEM.   # noqa: E501

        :return: The request of this CertSigningReqSpec.  # noqa: E501
        :rtype: str
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this CertSigningReqSpec.

        The certificate signing request (CSR) formatted as PEM. The certificate signing request (CSR) formatted as PEM.   # noqa: E501

        :param request: The request of this CertSigningReqSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and request is None:  # noqa: E501
            raise ValueError("Invalid value for `request`, must not be `None`")  # noqa: E501

        self._request = request

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CertSigningReqSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CertSigningReqSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.file_share_service_status import FileShareServiceStatus  # noqa: E501
from agilicus_api.rest import ApiException

class TestFileShareServiceStatus(unittest.TestCase):
    """FileShareServiceStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test FileShareServiceStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.file_share_service_status.FileShareServiceStatus()  # noqa: E501
        if include_optional :
            return FileShareServiceStatus(
                share_base_app_name = '0', 
                instance_id = 'asdas9Gk4asdaTH', 
                instance_org_id = '39ddfGAaslts8qX', 
                share_uri = 'https://share-4.cloud.egov.city/'
            )
        else :
            return FileShareServiceStatus(
        )

    def testFileShareServiceStatus(self):
        """Test FileShareServiceStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
